/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.common;

import io.grpc.Metadata;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Getter
@Log4j2
@Service
@RequiredArgsConstructor
public class ContextService {
    public static final String KEY_CLIENT_NAME = "CLIENT_NAME-bin";
    public static final String KEY_REQUEST_ID = "REQUEST_ID-bin";
    public static final String KEY_AUTHENTICATION_ID = "AUTHENTICATION-bin";
    public static final String KEY_JWT_TOKEN = "JWT_TOKEN-bin";
    private RequestAttributes requestAttributes;

    void readMetadata(Metadata headers) {
        var requestAttributesBuilder = RequestAttributes.builder();

        getRequestId(headers).ifPresent(id -> requestAttributesBuilder.requestId(new String(id)));
        getClientName(headers).ifPresent(name -> requestAttributesBuilder.clientName(new String(name)));
        getJwtToken(headers).ifPresent(token -> requestAttributesBuilder.jwtToken(new String(token)));
        getAuthentication(headers).ifPresent(saml -> requestAttributesBuilder.samlToken(new String(saml)));

        requestAttributes = requestAttributesBuilder.build();
    }

    Optional<byte[]> getRequestId(Metadata headers) {
        return Optional.ofNullable(headers.get(ContextService.createKeyOf(ContextService.KEY_REQUEST_ID)));
    }

    Optional<byte[]> getClientName(Metadata headers) {
        return Optional.ofNullable(headers.get(ContextService.createKeyOf(ContextService.KEY_CLIENT_NAME)));
    }

    Optional<byte[]> getAuthentication(Metadata headers) {
        return Optional.ofNullable(headers.get(ContextService.createKeyOf(ContextService.KEY_AUTHENTICATION_ID)));
    }

    Optional<byte[]> getJwtToken(Metadata headers) {
        return Optional.ofNullable(headers.get(ContextService.createKeyOf(ContextService.KEY_JWT_TOKEN)));
    }

    static Metadata.Key<byte[]> createKeyOf(String key) {
        return Metadata.Key.of(key, Metadata.BINARY_BYTE_MARSHALLER);
    }
}
