/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.info.nachricht;

import io.grpc.Status;
import io.grpc.stub.StreamObserver;
import jakarta.validation.ConstraintViolationException;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
@RequiredArgsConstructor
public class NachrichtenGrpcService extends NachrichtServiceGrpc.NachrichtServiceImplBase {
    private final NachrichtenService nachrichtService;

    @Override
    public void saveNewNachricht(GrpcNewNachrichtRequest request,
                                 StreamObserver<GrpcNewNachrichtReply> responseObserver) {
        try {
            saveNachricht(request);
        } catch (ConstraintViolationException cve) {
            responseObserver.onError(Status.INVALID_ARGUMENT.withDescription(cve.getMessage()).asRuntimeException());
        }

        responseObserver.onNext(GrpcNewNachrichtReply.newBuilder().setStatus("ok").build());
        responseObserver.onCompleted();
    }

    private void saveNachricht(GrpcNewNachrichtRequest request) {
        nachrichtService.save(NachrichtEvent.builder()
            .postfachId(request.getNachricht().getPostfachId())
            .nachrichtenListUrl(request.getNachricht().getNachrichtenListUrl()).build());
    }

    @Override
    public void finishNachricht(GrpcFinishedNachrichtRequest request,
                                StreamObserver<GrpcFinishedNachrichtReply> responseObserver) {
        // TODO: finish nachricht and delete nachricht event from db

        responseObserver.onNext(GrpcFinishedNachrichtReply.newBuilder().setStatus("ok").build());
        responseObserver.onCompleted();
    }
}
