/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.common;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

import static de.ozgcloud.info.common.MetadataTestFactory.*;
import static org.assertj.core.api.Assertions.*;

@ExtendWith(MockitoExtension.class)
class ContextServiceTest {
    @Spy
    @InjectMocks
    private ContextService contextService;

    @Nested
    class TestCallContext {

        @BeforeEach
        void init() {
            contextService.readMetadata(MetadataTestFactory.create());
        }

        @Test
        void shouldGetRequestId() {
            var requestId = contextService.getRequestId(MetadataTestFactory.create());

            assertThat(requestId).isPresent().hasValue(REQUEST_ID_BYTES);
        }

        @Test
        void shouldGetClientName() {
            var clientName = contextService.getClientName(MetadataTestFactory.create());

            assertThat(clientName).isPresent().hasValue(CLIENT_NAME_BYTES);
        }

        @Test
        void shouldGetAuthentication() {
            var clientName = contextService.getAuthentication(MetadataTestFactory.create());

            assertThat(clientName).isPresent().hasValue(SAML_TOKEN_BYTES);
        }

        @Test
        void shouldReadRequestAttributesRequestId() {
            assertThat(contextService.getRequestAttributes().getRequestId()).isEqualTo(new String(REQUEST_ID_BYTES));
        }

        @Test
        void shouldReadRequestAttributesClientName() {
            assertThat(contextService.getRequestAttributes().getClientName()).isEqualTo(new String(CLIENT_NAME_BYTES));
        }

        @Test
        void shouldReadRequestAttributesAuth() {
            assertThat(contextService.getRequestAttributes().getSamlToken()).isEqualTo(new String(SAML_TOKEN_BYTES));
        }

        @Test
        void shouldReadRequestAttributesJwtToken() {
            assertThat(contextService.getRequestAttributes().getJwtToken()).isNotEmpty();
        }
    }

    @Nested
    class TestEmptyCallContext {
        @BeforeEach
        void init() {
            contextService.readMetadata(MetadataTestFactory.createEmpty());
        }

        @Test
        void shouldReadRequestAttributesRequestId() {
            assertThat(contextService.getRequestAttributes().getRequestId()).isNotEmpty();
        }

        @Test
        void shouldReadRequestAttributesClientName() {
            assertThat(contextService.getRequestAttributes().getClientName()).isNull();
        }

        @Test
        void shouldReadRequestAttributesSamlToken() {
            assertThat(contextService.getRequestAttributes().getSamlToken()).isNull();
        }
    }
}