/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.common;

import de.ozgcloud.info.JwtTokenProvider;
import io.grpc.Metadata;

import java.util.UUID;

import static de.ozgcloud.info.common.ContextService.*;

public class MetadataTestFactory {
    public static byte[] CLIENT_NAME_BYTES = "ANTRAGSRAUM".getBytes();
    public static byte[] REQUEST_ID_BYTES = UUID.randomUUID().toString().getBytes();
    public static byte[] SAML_TOKEN_BYTES = UUID.randomUUID().toString().getBytes();
    public static String JWT_AUTH_TOKEN = JwtTokenProvider.generate(UserTestFactory.create());

    public static Metadata create() {
        var metadata = new Metadata();

        metadata.put(createKeyOf(KEY_CLIENT_NAME), CLIENT_NAME_BYTES);
        metadata.put(createKeyOf(KEY_REQUEST_ID), REQUEST_ID_BYTES);
        metadata.put(createKeyOf(KEY_AUTHENTICATION_ID), SAML_TOKEN_BYTES);
        metadata.put(createKeyOf(KEY_JWT_TOKEN), JWT_AUTH_TOKEN.getBytes());

        return metadata;
    }

    public static Metadata createEmpty() {
        return new Metadata();
    }

    public static Metadata.Key<byte[]> createKeyOf(String key) {
        return Metadata.Key.of(key, Metadata.BINARY_BYTE_MARSHALLER);
    }
}
