/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.infomanager;

import static de.ozgcloud.info.NachrichtEventTestFactory.POSTKORB_HANDLE;
import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.assertThatExceptionOfType;

import de.ozgcloud.info.GrpcInformationRequest;
import de.ozgcloud.info.InformationServiceGrpc;
import de.ozgcloud.info.SecurityConfiguration;
import de.ozgcloud.info.common.UserTestFactory;
import io.grpc.StatusRuntimeException;
import net.devh.boot.grpc.client.inject.GrpcClient;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.DirtiesContext;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;

@SpringBootTest(properties = {
    "grpc.server.inProcessName=test",
    "grpc.server.port=-1",
    "grpc.client.inProcess.address=in-process:test"
})
@SpringJUnitConfig(classes = {UserWithEventsConfiguration.class, InformationGrpcTestConfiguration.class,
    SecurityConfiguration.class})
@DirtiesContext
class InformationGrpcServiceWithEventsITCase {
    @GrpcClient("inProcess")
    private InformationServiceGrpc.InformationServiceBlockingStub service;

    @Nested
    class TestInformationAvailable {
        @Test
        void shouldLoadInformation() {
            var request = GrpcInformationRequest.newBuilder().setPostfachId(UserTestFactory.POSTKORB_HANDLE).build();

            var response = service.getInformation(request);

            var values = response.getNachrichtenList();
            assertThat(values).hasSize(1);
            assertThat(values.get(0).getPostfachId()).isEqualTo(POSTKORB_HANDLE);
        }
    }

    @Nested
    class TestNoAccess {

        @Test
        void responseShouldThrowStatusRuntimeException() {
            var request = GrpcInformationRequest.newBuilder().setPostfachId("not_the_postfach_id_of_the_user").build();

            assertThatExceptionOfType(StatusRuntimeException.class).isThrownBy(() -> service.getInformation(request));
        }
    }
}