/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.infomanager;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import de.ozgcloud.info.JwtTokenProvider;
import de.ozgcloud.info.NachrichtEventTestFactory;
import de.ozgcloud.info.common.ContextService;
import de.ozgcloud.info.common.JwtTokenVerifier;
import java.util.List;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientAutoConfiguration;
import net.devh.boot.grpc.client.autoconfigure.GrpcClientTraceAutoConfiguration;
import net.devh.boot.grpc.common.autoconfigure.GrpcCommonCodecAutoConfiguration;
import net.devh.boot.grpc.common.autoconfigure.GrpcCommonTraceAutoConfiguration;
import net.devh.boot.grpc.server.autoconfigure.GrpcServerAutoConfiguration;
import net.devh.boot.grpc.server.autoconfigure.GrpcServerFactoryAutoConfiguration;
import net.devh.boot.grpc.server.autoconfigure.GrpcServerSecurityAutoConfiguration;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.ImportAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.test.util.ReflectionTestUtils;

@Log4j2
@Configuration
@ImportAutoConfiguration({
    GrpcCommonCodecAutoConfiguration.class,
    GrpcCommonTraceAutoConfiguration.class,
    GrpcServerAutoConfiguration.class,
    GrpcServerFactoryAutoConfiguration.class,
    GrpcServerSecurityAutoConfiguration.class,
    GrpcClientAutoConfiguration.class,
    GrpcClientTraceAutoConfiguration.class})
public class InformationGrpcTestConfiguration {
    @Autowired
    ContextService contextService;

    @Bean
    InformationService informationService() {
        var service = mock(InformationService.class);
        when(service.getInformationOfPostfach(NachrichtEventTestFactory.POSTKORB_HANDLE)).thenReturn(
            List.of(NachrichtEventTestFactory.create()));
        when(service.getInformationOfPostfach(NachrichtEventTestFactory.EMPTY_POSTFACH_HANDLE)).thenReturn(List.of());
        return service;
    }

    @Bean
    InformationRepository informationRepository() {
        return mock(InformationRepository.class);
    }


    @Bean
    InfoManagerProperties infoManagerProperties() {
        return new InfoManagerProperties();
    }

    @Bean
    JwtTokenVerifier jwtTokenVerifier() {
        var tokenVerifier = new JwtTokenVerifier();
        ReflectionTestUtils.setField(tokenVerifier, "jwtSecret", JwtTokenProvider.JWT_SECRET);
        return tokenVerifier;
    }

    @Bean
    InformationGrpcService informationGrpcService() {
        return new InformationGrpcService(informationService(), contextService, infoManagerProperties(),
            jwtTokenVerifier());
    }
}
