/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.infomanager;

import static de.ozgcloud.info.NachrichtEventTestFactory.EMPTY_POSTFACH_HANDLE;

import de.ozgcloud.info.JwtTokenProvider;
import de.ozgcloud.info.common.ContextService;
import de.ozgcloud.info.common.RequestAttributes;
import de.ozgcloud.info.common.UserTestFactory;
import java.util.UUID;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.test.util.ReflectionTestUtils;

@Configuration
public class UserWithOutEventsConfiguration {
    RequestAttributes requestAttributes() {
        return RequestAttributes.builder()
            .clientName("Antragsraum")
            .requestId(UUID.randomUUID().toString())
            .jwtToken(JwtTokenProvider.generate(UserTestFactory.createBuilder()
                .postkorbHandle(EMPTY_POSTFACH_HANDLE)
                .build())).build();
    }

    @Bean
    ContextService contextService() {
        var contextService = new ContextService();
        ReflectionTestUtils.setField(contextService, "requestAttributes", requestAttributes());
        return contextService;
    }
}
