/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.nachricht;

import static org.assertj.core.api.Assertions.assertThat;

import de.ozgcloud.info.NachrichtEventTestFactory;
import de.ozgcloud.info.SecurityConfiguration;
import net.devh.boot.grpc.client.inject.GrpcClient;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.DirtiesContext;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;

@SpringBootTest(properties = {
    "grpc.server.inProcessName=test",
    "grpc.server.port=-1",
    "grpc.client.inProcess.address=in-process:test"
})
@SpringJUnitConfig(classes = {NachrichtEventGrpcTestConfiguration.class, SecurityConfiguration.class})
@DirtiesContext
class NachrichtEventGrpcServiceITCase {

    @GrpcClient("inProcess")
    private NachrichtServiceGrpc.NachrichtServiceBlockingStub service;

    @Nested
    class TestSaveNewNachrichtEvent {
        private final NachrichtEvent nachrichtEvent = NachrichtEventTestFactory.create();

        private final GrpcNewNachrichtRequest newNachrichtRequest = GrpcNewNachrichtRequest.newBuilder().setNachricht(
            GrpcNachricht.newBuilder()
                .setPostfachId(nachrichtEvent.getPostfachId())
                .setNachrichtenListUrl(nachrichtEvent.getNachrichtenListUrl())
        ).build();

        @Test
        @DirtiesContext
        void shouldSaveNewNachricht() {
            var response = service.saveNewNachricht(newNachrichtRequest);

            assertThat(response).isNotNull();
        }
    }

    @Nested
    class TestFinishNachrichtEvent {

        private final GrpcFinishedNachrichtRequest finishedNachrichtRequest =
            GrpcFinishedNachrichtRequest.newBuilder().build();

        @Test
        @DirtiesContext
        void shouldFinishNachricht() {
            var response = service.finishNachricht(finishedNachrichtRequest);

            assertThat(response).isNotNull();
        }
    }
}