/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.info.nachricht;

import static org.assertj.core.api.Assertions.assertThat;
import static org.junit.jupiter.api.Assertions.assertThrows;

import de.ozgcloud.info.MongoDBTestContainerConfig;
import de.ozgcloud.info.NachrichtEventTestFactory;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.data.mongo.DataMongoTest;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.test.context.ContextConfiguration;
import org.testcontainers.junit.jupiter.Testcontainers;


@DataMongoTest
@Testcontainers
@ContextConfiguration(classes = MongoDBTestContainerConfig.class)
public class NachrichtEventRepositoryITCase {
    @Autowired
    NachrichtenRepository repository;

    @Nested
    class TestNewNachrichtEvent {

        @BeforeEach
        void init() {
            repository.deleteAll();
        }

        @Test
        void shouldSaveNachricht() {
            repository.save(NachrichtEventTestFactory.create());

            var nachricht =
                repository.findByPostfachIdAndNachrichtenListUrl(NachrichtEventTestFactory.POSTKORB_HANDLE,
                    NachrichtEventTestFactory.URL);

            assertThat(nachricht).isPresent();
        }
    }

    @Nested
    class TestExistingNachrichtEvent {

        @BeforeEach
        void init() {
            repository.deleteAll();
            repository.save(NachrichtEventTestFactory.create());
        }

        @Test
        void shouldThrowDuplicateKeyException() {
            assertThrows(DuplicateKeyException.class, () -> repository.save(NachrichtEventTestFactory.create()));
        }
    }
}
